==> tds-4.3.23-sources.jar: thredds/server/wcs/VersionHandler.java <==
/*
 * Copyright 1998-2009 University Corporation for Atmospheric Research/Unidata
 *
 * Portions of this software were developed by the Unidata Program at the
 * University Corporation for Atmospheric Research.
 *
 * Access and use of this software shall impose the following obligations
 * and understandings on the user. The user is granted the right, without
 * any fee or cost, to use, copy, modify, alter, enhance and distribute
 * this software, and any derivative works thereof, and its supporting
 * documentation for any purpose whatsoever, provided that this entire
 * notice appears in all copies of the software, derivative works and
 * supporting documentation.  Further, UCAR requests that the user credit
 * UCAR/Unidata in any publications that result from the use of this
 * software or in any product that includes this software. The names UCAR
 * and/or Unidata, however, may not be used in any advertising or publicity
 * to endorse or promote any products or commercial entity unless specific
 * written permission is obtained from UCAR/Unidata. The user also
 * understands that UCAR/Unidata is not obligated to provide the user with
 * any support, consulting, training or assistance of any kind with regard
 * to the use, operation and performance of this software nor to provide
 * the user with any updates, revisions, new versions or "bug fixes."
 *
 * THIS SOFTWARE IS PROVIDED BY UCAR/UNIDATA "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL UCAR/UNIDATA BE LIABLE FOR ANY SPECIAL,
 * INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
 * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
 * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 * WITH THE ACCESS, USE OR PERFORMANCE OF THIS SOFTWARE.
 */
package thredds.server.wcs;

import ucar.nc2.util.DiskCache2;

import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.ServletException;
import java.io.IOException;

import thredds.util.Version;

/**
 * Each implementation handles a different version of WCS requests. 
 *
 * @author edavis
 * @since 4.0
 */
public interface VersionHandler
{
  public Version getVersion();

  public VersionHandler setDiskCache( DiskCache2 diskCache );

  /**
   * Set whether generated files are deleted immediately after sent (true) or handled by cache (false).
   *
   * Note: currently (2008-03-05), each request generates a unique file. So caching doesn't make much sense. 
   *
   * @param deleteImmediately if true, delete immediately, otherwise allow cache to handle.   
   * @return this VersionHandler
   */
  public VersionHandler setDeleteImmediately( boolean deleteImmediately);

  public void handleKVP( HttpServlet servlet,
                         HttpServletRequest req,
                         HttpServletResponse res )
          throws ServletException, IOException;

  public void handleExceptionReport( HttpServletResponse res,
                                     String code, String locator,
                                     String message )
          throws IOException;

  public void handleExceptionReport( HttpServletResponse res,
                                     String code, String locator,
                                     Throwable t )
          throws IOException;

}

==> tds-4.4.1-sources.jar: thredds/server/wcs/VersionHandler.java <==
/*
 * Copyright 1998-2009 University Corporation for Atmospheric Research/Unidata
 *
 * Portions of this software were developed by the Unidata Program at the
 * University Corporation for Atmospheric Research.
 *
 * Access and use of this software shall impose the following obligations
 * and understandings on the user. The user is granted the right, without
 * any fee or cost, to use, copy, modify, alter, enhance and distribute
 * this software, and any derivative works thereof, and its supporting
 * documentation for any purpose whatsoever, provided that this entire
 * notice appears in all copies of the software, derivative works and
 * supporting documentation.  Further, UCAR requests that the user credit
 * UCAR/Unidata in any publications that result from the use of this
 * software or in any product that includes this software. The names UCAR
 * and/or Unidata, however, may not be used in any advertising or publicity
 * to endorse or promote any products or commercial entity unless specific
 * written permission is obtained from UCAR/Unidata. The user also
 * understands that UCAR/Unidata is not obligated to provide the user with
 * any support, consulting, training or assistance of any kind with regard
 * to the use, operation and performance of this software nor to provide
 * the user with any updates, revisions, new versions or "bug fixes."
 *
 * THIS SOFTWARE IS PROVIDED BY UCAR/UNIDATA "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL UCAR/UNIDATA BE LIABLE FOR ANY SPECIAL,
 * INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
 * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
 * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 * WITH THE ACCESS, USE OR PERFORMANCE OF THIS SOFTWARE.
 */
package thredds.server.wcs;

import ucar.nc2.util.DiskCache2;

import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.ServletException;
import java.io.IOException;

import thredds.util.Version;

/**
 * Each implementation handles a different version of WCS requests.
 *
 * @author edavis
 * @since 4.0
 */
public interface VersionHandler {

  public Version getVersion();

  public VersionHandler setDiskCache(DiskCache2 diskCache);

  /**
   * Set whether generated files are deleted immediately after sent (true) or handled by cache (false).
   * <p/>
   * Note: currently (2008-03-05), each request generates a unique file. So caching doesn't make much sense.
   *
   * @param deleteImmediately if true, delete immediately, otherwise allow cache to handle.
   * @return this VersionHandler
   */
  public VersionHandler setDeleteImmediately(boolean deleteImmediately);

  public void handleKVP(HttpServlet servlet,
                        HttpServletRequest req,
                        HttpServletResponse res)
          throws ServletException, IOException;

  public void handleExceptionReport(HttpServletResponse res,
                                    String code, String locator,
                                    String message)
          throws IOException;

  public void handleExceptionReport(HttpServletResponse res,
                                    String code, String locator,
                                    Throwable t)
          throws IOException;

}
